==> huaweicloudsdkvpc-3.1.123-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/delete_clouddcn_subnets_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteClouddcnSubnetsTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resource_id': 'str',
        'tag_key': 'str'
    }

    attribute_map = {
        'resource_id': 'resource_id',
        'tag_key': 'tag_key'
    }

    def __init__(self, resource_id=None, tag_key=None):
        """DeleteClouddcnSubnetsTagRequest

        The model defined in huaweicloud sdk

        :param resource_id: Clouddcn子网的id
        :type resource_id: str
        :param tag_key: 待删除标签的key
        :type tag_key: str
        """
        
        

        self._resource_id = None
        self._tag_key = None
        self.discriminator = None

        self.resource_id = resource_id
        self.tag_key = tag_key

    @property
    def resource_id(self):
        """Gets the resource_id of this DeleteClouddcnSubnetsTagRequest.

        Clouddcn子网的id

        :return: The resource_id of this DeleteClouddcnSubnetsTagRequest.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this DeleteClouddcnSubnetsTagRequest.

        Clouddcn子网的id

        :param resource_id: The resource_id of this DeleteClouddcnSubnetsTagRequest.
        :type resource_id: str
        """
        self._resource_id = resource_id

    @property
    def tag_key(self):
        """Gets the tag_key of this DeleteClouddcnSubnetsTagRequest.

        待删除标签的key

        :return: The tag_key of this DeleteClouddcnSubnetsTagRequest.
        :rtype: str
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        """Sets the tag_key of this DeleteClouddcnSubnetsTagRequest.

        待删除标签的key

        :param tag_key: The tag_key of this DeleteClouddcnSubnetsTagRequest.
        :type tag_key: str
        """
        self._tag_key = tag_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteClouddcnSubnetsTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/delete_clouddcn_subnets_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteClouddcnSubnetsTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resource_id': 'str',
        'tag_key': 'str'
    }

    attribute_map = {
        'resource_id': 'resource_id',
        'tag_key': 'tag_key'
    }

    def __init__(self, resource_id=None, tag_key=None):
        r"""DeleteClouddcnSubnetsTagRequest

        The model defined in huaweicloud sdk

        :param resource_id: Clouddcn子网的id
        :type resource_id: str
        :param tag_key: 待删除标签的key
        :type tag_key: str
        """
        
        

        self._resource_id = None
        self._tag_key = None
        self.discriminator = None

        self.resource_id = resource_id
        self.tag_key = tag_key

    @property
    def resource_id(self):
        r"""Gets the resource_id of this DeleteClouddcnSubnetsTagRequest.

        Clouddcn子网的id

        :return: The resource_id of this DeleteClouddcnSubnetsTagRequest.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        r"""Sets the resource_id of this DeleteClouddcnSubnetsTagRequest.

        Clouddcn子网的id

        :param resource_id: The resource_id of this DeleteClouddcnSubnetsTagRequest.
        :type resource_id: str
        """
        self._resource_id = resource_id

    @property
    def tag_key(self):
        r"""Gets the tag_key of this DeleteClouddcnSubnetsTagRequest.

        待删除标签的key

        :return: The tag_key of this DeleteClouddcnSubnetsTagRequest.
        :rtype: str
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        r"""Sets the tag_key of this DeleteClouddcnSubnetsTagRequest.

        待删除标签的key

        :param tag_key: The tag_key of this DeleteClouddcnSubnetsTagRequest.
        :type tag_key: str
        """
        self._tag_key = tag_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteClouddcnSubnetsTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
